Learn R Programming

latentnet (version 2.7.0)

ergmm.drawpie: Draw a pie chart at a specified location.

Description

Used by plot.ergmm to draw pie charts to visualize soft clusterings when pie=TRUE. Exported as a courtesy to dependent packages.

Usage

ergmm.drawpie(center, radius, probs, n = 50, cols = 1:length(probs), ...)

Arguments

center
A numeric vector of length 2, specifying the horizontal and the vertical coordinates of its center.
radius
Radius of the pie chart.
probs
A vector of probabilities/weights of each sector; they do not have to sum to 1.
n
Number of points to use to approximate the "circle".
cols
A vector of colors to use for the sectors.
...
Additional arguments, currently unused.

See Also

plot.ergmm

Examples

Run this code
plot(c(0,sum(1:11))*2,c(-10,10),type="n",asp=1)
for(i in 1:10) ergmm.drawpie(c(sum(1:i)*2,0), radius=i, probs=1:(i+1))

Run the code above in your browser using DataLab