Learn R Programming

latentnet (version 2.7.0)

ergmm.par.list.object: A List of ERGMM Parameter Configuration

Description

A class ergmm.par.list to represent a series of parameter configurations for the same exponential random graph mixed model.

Arguments

Details

[[ operator with a numeric or integer index returns a list with the the configuration with that index. [ operator given a numeric vector returns a ergmm.par.list object with the subset of configurations with the indices given. The structure of ergmm.par.list is derived from named lists, with each entry having an additional dimension (always the first one), indexed by configuration. That is, scalars become vectors, vectors become matrixes with the original vectors in rows, and matrixes become 3-dimensional arrays, with the original matrixes indexed by their first dimension. See terms.ergmm for comon elements of these configurations.

In some cases, such as when representing MCMC or optimization output, the object may also have some of the following elements: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

See Also

ergmm