ergmm prior
specification. Typically only used when calling ergmm. It is
used to supply the parameters of the prior distribution of the model,
to overwrite those specified in the model formula, and to supply
miscellaneous prior parameters.ergmm.prior(..., adjust.beta.var = TRUE)ergmm, terms.ergmm