Learn R Programming

latentnet (version 2.7.0)

merge.ergmm: Merge two or more replications of ERGMM fits

Description

merge.ergmm prodcues a ergmm object containing the combined MCMC output (and derived estimates) of several ergmm objects produced with the same input parameters but different starting values, random seeds, etc..

Usage

## S3 method for class 'ergmm':
merge(x, y, \dots, verbose = FALSE)

Arguments

x
The first ergmm object to be merged.
y
The second ergmm object to be merged.
...
Additional ergmm objects to be merged.
verbose
If TRUE, marks the progress of merging.

Value

  • An object of class ergmm.

See Also

ergmm.object, ergmm

Examples

Run this code
data(sampson)
# Run two short MCMC-based fits.
samp.fit1 <- ergmm(samplike ~ euclidean(d=2, G=3),
  control=ergmm.control(burnin=1000,interval=10,sample.size=2000))
samp.fit2 <- ergmm(samplike ~ euclidean(d=2, G=3),
  control=ergmm.control(burnin=1000,interval=10,sample.size=2000))

# Combine them, and summarize the result.
samp.fit <-  merge.ergmm(samp.fit1,samp.fit2)
summary(samp.fit)

Run the code above in your browser using DataLab