ergmm.pY.-, lpY.-, EY.-,
dlpY.deta.-, dlpY.ddispersion.-, lpYc.-, rsm.-, followed by the family's Rname,
for the respective family's Rname, representing the family's
likelihood, log-likelihood, expectation, derivative of log-likelihood with repect to the linear predictor,
derivative of log-likelihood with respect to the dispersion parameter,
log-normalizing-constant, and random sociomatrix generation functions. On the C side, similar functions exist, but becuase of static
typing, are also provided for ``continuous'' versions of those
families. These should not be used on their own, but are used in
estimating MKL positions from the posterior distribution.